import { NextRequest, NextResponse } from 'next/server';
import { deletePropertyByUrl } from '@/lib/database';

// DELETE /api/urls/[encodedUrl]/properties/[property] - Delete a property from a URL
export async function DELETE(
  request: NextRequest,
  { params }: { params: { encodedUrl: string; property: string } }
) {
  try {
    const url = decodeURIComponent(params.encodedUrl);
    const property = decodeURIComponent(params.property);
    
    console.log('[API] DELETE request - URL:', url, 'Property:', property);

    if (!url || !property) {
      console.log('[API] Missing required parameters');
      return NextResponse.json(
        { error: 'URL and property name are required' },
        { status: 400 }
      );
    }

    console.log('[API] Calling deletePropertyByUrl...');
    await deletePropertyByUrl(url, property);
    
    console.log('[API] Successfully deleted property:', property, 'from URL:', url);
    
    return NextResponse.json(
      { 
        message: 'Property deleted successfully', 
        property: property,
        url: url 
      },
      { status: 200 }
    );
  } catch (error) {
    console.error('[API] Delete error:', error);
    
    return NextResponse.json(
      { 
        error: 'Failed to delete property',
        details: error instanceof Error ? error.message : 'Unknown error',
        property: params.property,
        url: params.encodedUrl
      },
      { status: 500 }
    );
  }
}